%macro DimAnim(Dimension=,Path=,default_device=fixanim);

 /* Clear the graphics catalog */
proc greplay igout=work.gseg nofs;
delete _all_;
run; quit;

libname gdevice0 "&Path";
proc gdevice nofs cat=gdevice0.devices;
delete fixanim;
copy gifanim from=sashelp.devices newname=fixanim;
modify fixanim hsize=0 vsize=0;
run;
quit;

GOPTIONS RESET=all;

ods noresults;
ods listing close;

ods html path  = "&Path" (url=none) /* folder for the HTML file  */
        gpath  = "&Path"            /* folder for the graph file */ 
         file  = "LB_&Dimension.ByAgeANIM.html"
                 (title="Animated GIF of Student &Dimension By Age")
                  /* custom title for browser frame */
         style = styles.minimal
	   gtitle gfootnote;

GOPTIONS DEVICE=gif XPIXELS=740 YPIXELS=555; /* for my web browser,
                    use all available space, but avoid scrolling */

 /* Create a placeholder, but this image will never display.  */
PROC GSLIDE NAME="LB_&Dimension"; /* name.gif will be put in GPATH */
TITLE1 'animated gif placeholder';
RUN;
QUIT;

ods html close;

ods listing;

GOPTIONS RESET=all;

 /* Create the animated gif using the same file */

FILENAME animout "&Path.\LB_&Dimension..gif";

GOPTIONS NOBORDER
HTEXT = 3 FTEXT = 'Georgia/Bold'
CTEXT = 'CX000000';

GOPTIONS DEVICE = &default_device. XPIXELS = 740 YPIXELS = 555
         GSFNAME = animout
         ITERATION = 7 /* max value is ?, how make it continuous loop? */
         DELAY = 100;  /* time unit is ? */

proc sort data=sashelp.class out=work.sorted;
by Age;
run;

data work.ToChart;
set work.sorted end=lastone;
by Age;
if first.Age
then do;
  GroupNumber + 1;
  call symput('AgeGroup'||trim(left(GroupNumber)),trim(left(Age)));
end;
output;
if lastone;
call symput('Count',GroupNumber);
run;

proc means data=sashelp.class noprint max;
var &Dimension;
output out=FoundMax Max=MaxValue;
run;

data _null_;
set FoundMax;
call symput('MaxValueOfDimension',trim(left(MaxValue)));
run;

%do i = 1 %to &Count;
%if &i eq 1 %then %do;
GOPTIONS GSFMODE=replace;
%end;
%else %do;
GOPTIONS GSFMODE=append;
%end;
TITLE1
H = 3.4 F = 'Georgia/Bold'
"&Dimension of Students Who Are Age "
C = CXFF0000
"&&AgeGroup&i"
J = C
C = CX0000FF
"Maximum &Dimension of Any Student is &MaxValueOfDimension";
PATTERN1 V = solid C = CXCCCCCC R = 99;
AXIS1 LABEL = NONE MAJOR = NONE MINOR = NONE STYLE = 0
VALUE = (J = R); /* right-justify the bar label against the left end of the bar */
AXIS2 LABEL = NONE MAJOR = NONE MINOR = NONE STYLE = 0
ORDER = (0 &MaxValueOfDimension)
VALUE = (tick=1 '0' tick=2 C = CX0000FF "&MaxValueOfDimension")
OFFSET = ( +3, +7 ); /* insert some extra white space between label and bar */;
FOOTNOTE1 H = 2.4 F = 'Georgia/Bold'
"To terminate animation, or to Return, click on back arrow";
PROC GCHART DATA = work.ToChart(where=(Age eq &&AgeGroup&i));
HBAR Name /
SUMVAR = &dimension
SUMLABEL = "&Dimension"
WIDTH = 2
SPACE = 2
MAXIS = axis1
RAXIS = axis2
href = &MaxValueOfDimension
 /* cref = CX0000FF */
lref = 33;
RUN;
QUIT;
%end;

 /* end the animation */
DATA _null_;
FILE animout RECFM=N MOD;
PUT '3B'x;
RUN;

%mend DimAnim;

%DimAnim(Dimension=Height,Path=.\sas_graphics,default_device=gifanim);
%DimAnim(Dimension=Weight,Path=.\sas_graphics,default_device=gifanim);

%macro HeightWeightAnim(Dimension=,Path=,default_device=fixanim);

 /* Clear the graphics catalog */
proc greplay igout=work.gseg nofs;
delete _all_;
run; quit;

libname gdevice0 "&Path";
proc gdevice nofs cat=gdevice0.devices;
delete fixanim;
copy gifanim from=sashelp.devices newname=fixanim;
modify fixanim hsize=0 vsize=0;
run;
quit;

GOPTIONS RESET=all;

FILENAME animout CLEAR;

ods html path  = "&Path" (url=none) /* folder for the HTML file  */
        gpath  = "&Path"            /* folder for the graph file */ 
         file  = 'LB_HeightAndWeightByAgeANIM.html'
                 (title="Animated GIF of Student Height & Weight By Age")
                  /* custom title for browser frame */
         style = styles.minimal
	   gtitle gfootnote;

GOPTIONS DEVICE=gif XPIXELS=740 YPIXELS=555; /* for my web browser,
                    use all available space, but avoid scrolling */

 /* Create a placeholder, but this image will never display.  */
PROC GSLIDE NAME='LB_hgtwgtGF'; /* name.gif will be put in GPATH */
TITLE1 'animated gif placeholder';
RUN;
QUIT;

ods html close;

ods listing;

GOPTIONS RESET=all;

 /* Create the animated gif using the same file */

FILENAME animout "&Path.\LB_hgtwgtGF.gif";

GOPTIONS NOBORDER
HTEXT = 1.5 FTEXT = 'Georgia/Bold'
CTEXT = 'CX000000';

GOPTIONS DEVICE = &default_device. XPIXELS = 740 YPIXELS = 555
         GSFNAME = animout
         ITERATION = 7 /* max value is ?, how make it continuous loop? */
         DELAY = 100;  /* time unit is ? */

proc sort data=sashelp.class out=work.sorted;
by Age;
run;

data work.ToChart;
set work.sorted end=lastone;
by Age;
if first.Age
then do;
  GroupNumber + 1;
  call symput('AgeGroup'||trim(left(GroupNumber)),trim(left(Age)));
end;
output;
if lastone;
call symput('Count',GroupNumber);
run;

proc means data=work.ToChart noprint max;
var Height Weight;
output out=FoundMax Max=MaxHgt MaxWgt;
run;

data _null_;
set FoundMax;
call symput('MaxHeight',trim(left(MaxHgt)));
call symput('MaxWeight',trim(left(MaxWgt)));
run;

data work.ToChart(drop=Height Weight Sex);
length TypeOfMeasure $ 6;
set work.ToChart;
TypeOfMeasure = 'Height';
Measure = height;
output;
TypeOfMeasure = 'Weight';
Measure = weight;
output;
run;

proc means data=work.ToChart noprint max;
var &Dimension;
output out=FoundMax Max=MaxValue;
run;

data _null_;
set FoundMax;
call symput('MaxValueOfDimension',trim(left(MaxValue)));
run;

%do i = 1 %to &Count;
%if &i eq 1 %then %do;
GOPTIONS GSFMODE=replace;
%end;
%else %do;
GOPTIONS GSFMODE=append;
%end;
TITLE1
H = 2.4 F = 'Georgia/Bold'
C = CXFF9933
"Height "
C = CX000000
"and "
C = CX996633
"Weight "
C = CX000000
"of "
C = CX0000FF
"Students "
C = CX000000
"Who Are Age "
C = CXFF0000
"&&AgeGroup&i"
J = C
C = CXFF9933
"Maximum Height of Any Student is &MaxHeight"
J = C
C = CX996633
"Maximum Weight of Any Student is &MaxWeight";
PATTERN1 V = solid C = CXFF9933;
PATTERN2 V = solid C = CX996633;
AXIS1 LABEL = NONE MAJOR = NONE MINOR = NONE STYLE = 0
VALUE = (J = R TICK=1 C = CXFF9933 TICK=2 C = CX996633);
AXIS2
REFLABEL = (C = CXFF9933 "&MaxHeight" C = CX996633 "&MaxWeight")
LABEL = NONE MAJOR = NONE MINOR = NONE STYLE = 0
ORDER = (0 &MaxValueOfDimension)
VALUE = NONE
OFFSET = ( +3, +7 ); /* insert some extra white space between label and bar
                                                  and between reflabel and values list */;
AXIS3 LABEL = NONE VALUE = (J = R C = CX0000FF); /* right-justify the group label */
FOOTNOTE1 H = 2.4 F = 'Georgia/Bold'
"To terminate animation, or to Return, click on back arrow";
PROC GCHART DATA = work.ToChart(where=(Age eq &&AgeGroup&i));
HBAR TypeOfMeasure /
PATTERNID = MIDPOINT
GROUP = Name
SUMVAR = &dimension
SUMLABEL = "Height Weight"
WIDTH = 1.00
SPACE = 1.00
MAXIS = axis1
RAXIS = axis2
GAXIS = axis3
HREF = &MaxHeight &MaxWeight
LREF = 33;
RUN;
QUIT;
%end;

 /* end the animation */
DATA _null_;
FILE animout RECFM=N MOD;
PUT '3B'x;
RUN;

FILENAME animout CLEAR;

%mend HeightWeightAnim;

%HeightWeightAnim(Dimension=Measure,Path=.\sas_graphics,default_device=gifanim);