/* Create a macro variable to simplify substitution */
%let codepath=file:///C:\Program Files\SAS Institute\Shared Files\applets;
%let filepath=c:\web_server\wwwroot\sasweb;

/* Create a new HTML file*/
filename outfile "&filepath\javameta_html2.html";

data _null_;
   length codebase archive parent $100;
   codebase=quote("&codepath");
   archive=quote("metafile.zip");
   parent= quote("javameta_html2_allyears.txt");

   file outfile;
   put '<html>';
   put '<head>';
   put '<title>Example 3b: Building Metagraphics Files with JAVAMETA and Building the HTML File Using PUT Statements</title>';
   put '</head>';
   put '<body>';
   put '<applet archive=' archive;
   put '   codebase=' codebase;
   put '   code="MetaViewApplet.class"';  
   put '   width="640" height="480" align="TOP">';
   put '   <param name="ZoomControlEnabled" value="flase">';
   put '   <param name="BackgroundColor" value="0xffffff">';
   put '   <param name="Metacodes" value=' parent '>';

   put '</applet>';
   put '</body>';
   put '</html>';
run;

/* Deassign fileref */
filename outfile;

/* Summarize the data by YEAR, QUARTER and YEAR*QUARTER */
proc summary data=sashelp.prdsale;
   class year quarter;
   var actual;
   output out=prdsummary sum=actual;
run;

/* Post-process the summarized data to create the HTML variable
   holding the text for the drill-down. */
data yearsonly;
   set prdsummary(where=(_type_ eq 2));
   length htmlvar $600;
   /* MREF= defines the file of metacodes for drill-down actions */
   htmlvar='mref='||quote("javameta_html2_y"||put(year,4.)||'.txt');
run;

/* Use JAVAMETA device driver to create graphics metadata */
goptions reset=all dev=javameta
         colors=(blue yellow red cyan) ctext=black
         ftext="Helvetica" ftitle="Helvetica"
         htext=24 pt htitle=32 pt ;

/* Assign _WEBOUT. Remove any earlier version. */
filename _webout "&filepath\javameta_html2_allyears.txt";
%let sysrc=%sysfunc(fdelete(_webout));

/* The IMAGEMAP= and HTML= options add the MREF=
   to the metagraphics data */
 title1 '1993-1994 Sales';
proc gchart data=yearsonly imagemap=temp ;
   pie3d year / sumvar=actual  discrete nolegend value=arrow slice=arrow
                html=htmlvar;
run;
quit;

/* Assign _WEBOUT to a drill-down file. Remove any earlier version */
filename _webout "&filepath\javameta_html2_y1993.txt";
%let sysrc=%sysfunc(fdelete(_webout));

title1 '1993 Quarterly Sales';
goptions colors=(red cyan tan ltgray);

proc gchart data=prdsummary (where=(year eq 1993 and _type_=3));
   pie3d quarter / sumvar=actual discrete nolegend value=arrow slice=arrow;
run;
quit;

/* Assign _WEBOUT to a drill-down file. Remove any earlier version */
filename _webout "&filepath\javameta_html2_y1994.txt";
%let sysrc=%sysfunc(fdelete(_webout));

goptions colors=(red cyan tan ltgray);
title1 '1994 Quarterly Sales';

proc gchart data=prdsummary (where=(year eq 1994 and _type_ eq 3));
   pie3d quarter / sumvar=actual discrete nolegend value=arrow slice=arrow;
run;
quit;

/* Deassign fileref */
filename _webout
