/* Define the path to the web server space. This is the
   only line you have to change to run this example.    */
%let filepath=c:\web_server\wwwroot\sasweb;

filename odsout "&filepath";

/* Summarize the data - one observation per PRODUCT*YEAR combination */
proc summary data=sashelp.prdsale nway;
   class product year;
   var actual;
   output out=prdsummary sum=actual;
run;

/* Post-process the summarized data to add an HTML variable
   holding the text for the data tips - one unique tip per 
   subgroup. TIP= is a keyword. */
data prdsummary;
   set prdsummary;
   length htmlvar $100;
   htmlvar='tip=['||
           quote('Product  '||trim(product))
           ||' '||
           quote('Year       '||put(year,4.))
           ||' '||
           quote('Actual     '||trim(left(put(actual,dollar10.2))))
           ||']';
run;

/* Use JAVAMETA device driver to create graphics metadata */
goptions reset=all border dev=javameta
         colors=(blue yellow red cyan) ctext=black
         ftext="Helvetica" ftitle="Helvetica"
         htext=24 pt htitle=32 pt;

/* Use ODS to direct output to the HTML destination */
ods listing close;
ods html file='javameta_ods.html' path=odsout
   parameters=("DataTipStyle"="STICK");

/* The HTML= option adds the data tips to the
   metagraphics data. */
title1 'Actual Sales by Product';
proc gchart data=prdsummary;
   hbar3d product / sumvar=actual subgroup=year sum
                    shape=hexagon caxis=black cframe=ltgray
                    html=htmlvar;
run;
quit;

/* Close the HTML destination and open the LISTING destination */
ods html close;
ods listing;
