/* Summarize the data by YEAR, QUARTER and YEAR*QUARTER */
proc summary data=sashelp.prdsale;
   class year quarter;
   var actual;
   output out=prdsummary sum=actual;
run;

%let htmlpath=http://localhost/sasweb;
%let filepath=c:\web_server\wwwroot\sasweb;

/* Post-process the summarized data to create the HTML variable
   holding the text for the drill-down. MREF= is a keyword. */
data yearsonly;
   set prdsummary(where=(_type_ eq 2));
   length htmlvar $200;
   htmlvar='mref='||quote("&htmlpath/javameta_y"||put(year,4.)||'.txt');
run;

/* Use JAVAMETA device driver to create graphics metadata */
goptions reset=all dev=javameta
         colors=(blue yellow red cyan) ctext=black
         ftext="Helvetica" ftitle="Helvetica"
         htext=24 pt htitle=32 pt ;

/* The IMAGEMAP= and HTML= options add the MREF values to the
   metagraphics data */
filename _webout "&filepath\javameta_allyears.txt";
title1 '1993-1994 Sales';
proc gchart data=yearsonly imagemap=temp ;
   pie3d year / sumvar=actual discrete nolegend value=arrow
                slice=arrow html=htmlvar;
run;
quit;

/* Create the drill-down graphs */
filename _webout "&filepath\javameta_y1993.txt";
goptions colors=(red cyan tan ltgray);
title1 '1993 Quarterly Sales';
proc gchart data=prdsummary (where=(year eq 1993 and _type_=3));
   pie3d quarter / sumvar=actual discrete nolegend 
       value=arrow slice=arrow;
run;
quit;

filename _webout "&filepath\javameta_y1994.txt";
goptions colors=(red cyan tan ltgray);
title1 '1994 Quarterly Sales';
proc gchart data=prdsummary (where=(year eq 1994 and _type_ eq 3));
   pie3d quarter / sumvar=actual discrete nolegend value=arrow 
      slice=arrow;
run;
quit;

/* Deassign fileref */
filename _webout;
