/* Create a macro variable to simplify substitution */
%let codepath=file:///C:\Program Files\SAS Institute\Shared Files\applets;
%let filepath=c:\web_server\wwwroot\sasweb;

/* Create a new HTML file*/
filename outfile "&filepath\sasmeta_html.html";

data _null_;
   length codebase archive parent $100;
   codebase=quote("&codepath");
   archive=quote("metafile.zip");
   parent= quote("sasmeta_html_allyears.txt");

   file outfile;
   put '<html>';
   put '<head>';
   put '<title>Example 3: Building Metagraphics Files with SASMETA and Building the HTML File Using PUT Statements</title>';
   put '</head>';
   put '<body>';
   put '<applet archive=' archive;
   put '   codebase=' codebase;
   put '   code="MetaViewApplet.class"';  
   put '   width="640" height="480" align="TOP">';
   put '   <param name="ZoomControlEnabled" value="flase">';
   put '   <param name="BackgroundColor" value="0xffffff">';
   put '   <param name="Metacodes" value=' parent '>';

   put '</applet>';
   put '</body>';
   put '</html>';
run;

/* Deassign fileref */
filename outfile;

/* Summarize the data by YEAR, QUARTER and YEAR*QUARTER */
proc summary data=sashelp.prdsale;
   class year quarter;
   var actual;
   output out=prdsummary sum=actual;
run;

/* Post-process the summarized data to create the HTML variable
   holding the text for the drill-down. */
data yearsonly;
   set prdsummary(where=(_type_ eq 2));
   length htmlvar $600 menustring $100;
   /* MENU= defines pop-up menu text and actions */
   menustring='menu=['||
                quote('1993 by Quarter')||'= '||
                quote('1994 by Quarter')||'=]';
   /* MREF= defines the file of metacodes for drill-down actions */
   htmlvar='mref='||quote("sasmeta_html_y"||put(year,4.)||'.txt')||' '||menustring;
run;

/* Use SASMETA device driver to create graphics metadata */
goptions reset=all dev=sasmeta gsfname=imgdata
         colors=(blue yellow red cyan) ctext=black
         htext=24 pt htitle=32 pt ;

/* Assign IMGDATA. Remove any earlier version. */
filename imgdata "&filepath\sasmeta_html_allyears.txt";
%let sysrc=%sysfunc(fdelete(imgdata));

/* The IMAGEMAP= and HTML= options add the MREF= and MENU= values
   to the metagraphics data */
 title1 '1993-1994 Sales';
proc gchart data=yearsonly imagemap=temp ;
   pie3d year / sumvar=actual  discrete nolegend value=arrow slice=arrow
                html=htmlvar;
run;
quit;

/* Assign IMGDATA. Remove any earlier version. */
filename imgdata "&filepath\sasmeta_html_y1993.txt";
%let sysrc=%sysfunc(fdelete(imgdata));

title1 '1993 Quarterly Sales';
goptions colors=(red cyan tan ltgray);

proc gchart data=prdsummary (where=(year eq 1993 and _type_=3));
   pie3d quarter / sumvar=actual discrete nolegend value=arrow slice=arrow;
run;
quit;

/* Assign IMGDATA. Remove any earlier version. */
filename imgdata "&filepath\sasmeta_html_y1994.txt";
%let sysrc=%sysfunc(fdelete(imgdata));

goptions colors=(red cyan tan ltgray);
title1 '1994 Quarterly Sales';

proc gchart data=prdsummary (where=(year eq 1994 and _type_ eq 3));
   pie3d quarter / sumvar=actual discrete nolegend value=arrow slice=arrow;
run;
quit;

/* Deassign fileref */
filename imgdata;
